@@ -19,8 +19,10 @@ def check(func):
         except (AttributeError, TypeError):
             if 'HTTP_REFERER' in request.META:
                 return HttpResponseRedirect(request.META.get('HTTP_REFERER', '/'))
-            return HttpResponseServerError('"%s" object of type ``%s`` has no method ``get_absolute_url()``.' % (
-                unicode(follow.target), follow.target.__class__))
+            if follow:
+                return HttpResponseServerError('"%s" object of type ``%s`` has no method ``get_absolute_url()``.' % (
+                    unicode(follow.target), follow.target.__class__))
+            return HttpResponseServerError('No follow object and `next` parameter found.')
     return iCheck
 
 
